#
# Copyright (C) 2021  FreeIPA Contributors see COPYING for license
#

import os
import pytest

from ipatests.test_ipaserver.httptest import Unauthorized_HTTP_test
from ipatests.test_xmlrpc.xmlrpc_test import XMLRPC_test
from ipatests.util import assert_equal
from ipalib import api, create_api, errors
from ipapython.dn import DN
from ipapython.ipaldap import ldap_initialize
from ipaserver.plugins.ldap2 import ldap2

testgroup = 'testgroup'


@pytest.mark.tier1
class test_ldapcache(XMLRPC_test):

    def test_partial_cache(self, request):
        """Populate the cache with an automember entry and call
           automember-add-condition which will re-fetch the entry
           with a limited attribute set. If it gets more than it
           requests then it will error out.
        """
#        rpcclient = api.Backend.rpcclient
#        was_connected = rpcclient.isconnected()

#        if not was_connected:
#            rpcclient.connect()

        # Create our own api because the one generated for the tests is
        # a client-only api. Then we register in the commands and objects
        # we need for the test.
        myapi = create_api(mode=None)
        myapi.bootstrap(context='server', in_server=True, debug=True, log=None)
        myapi.finalize()

#        if not myapi.Backend.ldap2.isconnected():
#            myapi.Backend.ldap2.connect()
        myapi.Backend.ldap2.connect(ccache=os.environ.get('KRB5CCNAME', None))

        try:
            myapi.Command['automember_del'](testgroup, type='group')
        except errors.NotFound:
            pass
        try:
            myapi.Command['group_del'](testgroup)
        except errors.NotFound:
            pass
        myapi.Command['group_add'](testgroup)
        myapi.Command['automember_add'](
            testgroup, type='group', description='test automember rule'
        )
        myapi.Command['automember_mod'](
            testgroup, type='group',
            description='test automember rule description'
        )
        myapi.Command['automember_add_condition'](
            testgroup, type='group', key='uid',
            automemberinclusiveregex='uid'
        )
        myapi.Command['automember_add_condition']('testgroup',
            type='group', key='uidnumber',
            automemberinclusiveregex='uidnumber'
        )
        myapi.Command['automember_add_condition'](
            'testgroup', type='group', key='uid',
            automemberexclusiveregex='uid'
        )
